@@ -50,6 +50,7 @@ import optparse
 import StringIO
 import signal
 import json
+import textwrap
 
 
 def check_writable_dir(option, opt_str, value, parser):
@@ -108,7 +109,7 @@ def parse_options(input_args):
                       "authenticate against a cloud when "
                       "uploading/registering images")
 
-    parser.add_option("--print-sysprep", dest="print_sysprep", default=False,
+    parser.add_option("--print-syspreps", dest="print_syspreps", default=False,
                       help="print the enabled and disabled system preparation "
                       "operations for this input media", action="store_true")
 
@@ -121,6 +122,14 @@ def parse_options(input_args):
                       "input media", default=[], action="append",
                       metavar="SYSPREP")
 
+    parser.add_option("--print-sysprep-params", dest="print_sysprep_params",
+                      default=False, help="print the needed sysprep parameters"
+                      " for this input media", action="store_true")
+
+    parser.add_option("--sysprep-param", dest="sysprep_params", default=[],
+                      help="Add KEY=VALUE system preparation parameter",
+                      action="append")
+
     parser.add_option("--no-sysprep", dest="sysprep", default=True,
                       help="don't perform any system preparation operation",
                       action="store_false")
@@ -132,6 +141,10 @@ def parse_options(input_args):
                       help="register image with the cloud as public",
                       action="store_true")
 
+    parser.add_option("--allow-unsupported", dest="allow_unsupported",
+                      help="Proceed with the image creation even if the media "
+                      "is not supported", default=False, action="store_true")
+
     parser.add_option("--tmpdir", dest="tmp", type="string", default=None,
                       help="create large temporary image files under DIR",
                       metavar="DIR")
@@ -170,6 +183,16 @@ def parse_options(input_args):
         meta[key] = value
     options.metadata = meta
 
+    sysprep_params = {}
+    for p in options.sysprep_params:
+        try:
+            key, value = p.split('=', 1)
+        except ValueError:
+            raise FatalError("Sysprep parameter optiont: `%s' is not in "
+                             "KEY=VALUE format." % p)
+        sysprep_params[key] = value
+    options.sysprep_params = sysprep_params
+
     return options
 
 
@@ -177,9 +200,9 @@ def image_creator():
     options = parse_options(sys.argv[1:])
 
     if options.outfile is None and not options.upload and not \
-            options.print_sysprep:
-        raise FatalError("At least one of `-o', `-u' or `--print-sysprep' "
-                         "must be set")
+            options.print_syspreps and not options.print_sysprep_params:
+        raise FatalError("At least one of `-o', `-u', `--print-syspreps' or "
+                         "`--print-sysprep-params' must be set")
 
     if options.silent:
         out = SilentOutput()
@@ -253,7 +276,17 @@ def image_creator():
     try:
         snapshot = disk.snapshot()
 
-        image = disk.get_image(snapshot)
+        image = disk.get_image(snapshot, sysprep_params=options.sysprep_params)
+
+        if image.is_unsupported() and not options.allow_unsupported:
+            raise FatalError(
+                "The media seems to be unsupported.\n\n" +
+                textwrap.fill("To create an image from an unsupported media, "
+                              "you'll need to use the`--allow-unsupported' "
+                              "command line option. Using this is highly "
+                              "discouraged, since the resulting image will "
+                              "not be cleared out of sensitive data and will "
+                              "not get customized during the deployment."))
 
         for sysprep in options.disabled_syspreps:
             image.os.disable_sysprep(image.os.get_sysprep_by_name(sysprep))
@@ -261,10 +294,14 @@ def image_creator():
         for sysprep in options.enabled_syspreps:
             image.os.enable_sysprep(image.os.get_sysprep_by_name(sysprep))
 
-        if options.print_sysprep:
+        if options.print_syspreps:
             image.os.print_syspreps()
             out.output()
 
+        if options.print_sysprep_params:
+            image.os.print_sysprep_params()
+            out.output()
+
         if options.outfile is None and not options.upload:
             return 0
 
@@ -276,6 +313,9 @@ def image_creator():
         size = options.shrink and image.shrink() or image.size
         metadata.update(image.meta)
 
+        if image.is_unsupported():
+            metadata['EXCLUDE_ALL_TASKS'] = "yes"
+
         # Add command line metadata to the collected ones...
         metadata.update(options.metadata)
 
@@ -362,6 +402,10 @@ def main():
         sys.exit(ret)
     except FatalError as e:
         colored = sys.stderr.isatty()
+        warning = \
+            "The name of the executable has changed. If you want to use the " \
+            "user-friendly dialog-based program try `snf-image-creator'"
+        SimpleOutput(colored).warn(warning)
         SimpleOutput(colored).error(e)
         sys.exit(1)
 
