@@ -1,8 +1,8 @@
 
-__version__ = "0.6.1"
+__version__ = "0.6.2"
 __version_vcs_info__ = {
-    'branch': 'master',
-    'revid': '280a0e5',
-    'revno': 430}
+    'branch': 'hotfix-0.6.2',
+    'revid': '73cec8b',
+    'revno': 438}
 __version_user_email__ = "skalkoto@grnet.gr"
 __version_user_name__ = "Nikos Skalkotos"
